capture log close
log using icpsrcda-03-testing, replace text

//  program:    icpsrcda-03-testing.do
//  task:       Review 3 - Testing & Fit
//  project:    ICPSR CDA
//  author:     Trent Mize \ 2014-06-24
//	updated:	SNS		   \ 2017-07-16

*program setup
version 	14.0
clear 		all 
set 		linesize 80

//3.1b) Load the Data.
usecda 		cda_scireview3
 
//3.1c) Examine data, keep variables, drop missing, and  verify.
codebook, 	compact
keep 		faculty female fellow phd mcit3 mnas
misschk, 	gen(m)
tab 		mnumber
keep if 	mnumber==0
codebook 	faculty female fellow phd mcit3 mnas, compact   
sum 		faculty female fellow phd mcit3 mnas

//3.2) Computing a z-test. 
logit 		faculty i.female i.fellow phd mcit3 i.mnas, nolog

//3.3) Single Coefficient Wald Test. 
test 		1.female

//3.4) Single Coefficient LR Test. 
logit 		faculty i.female i.fellow phd mcit3 i.mnas
estimates 	store base
logit 		faculty i.fellow phd mcit3 i.mnas
estimates 	store nofemale
lrtest 		base nofemale

//3.5) Multiple Coefficients Wald Test.  
qui logit 	faculty i.female i.fellow phd mcit3 i.mnas
test 		mcit3 1.mnas

//3.6) Multiple Coefficients LR Test. 
logit 		faculty i.female i.fellow phd
estimates 	store nomcit3mnas
lrtest 		base nomcit3mnas

//3.7) Wald Test All Coefficients are Zero. 
qui logit 	faculty i.female i.fellow phd mcit3 i.mnas
test 		1.female 1.fellow phd mcit3 1.mnas

//3.8) LR Test All Coefficients are Zero. 
logit 		faculty
estimates 	store intercept
lrtest 		base intercept

//3.9) More Complicated Wald Tests. 
qui logit 	faculty i.female i.fellow phd mcit3 i.mnas
test 		mcit3 = 1.mnas
test 		1.female = 2*mcit3

//3.10) Compare BIC & AIC statistics across non-nested models. 
qui logit 	faculty i.female fellow
estimates 	store m1

qui logit 	faculty mcit3 
estimates 	store m2

qui logit 	faculty phd i.mnas
estimates 	store m3

qui logit 	faculty phd i.mnas i.female i.fellow
estimates 	store m4

estimates 	table m1 m2 m3 m4, b(%9.3f) star stats(bic aic)


//3.11) Compute and list residuals. 
logit 		faculty phd i.mnas i.female i.fellow
predict 	rstd, rs
sort 		rstd
list 		rstd faculty phd mnas female fellow in 1/20, clean // Note: 1=#
list 		rstd faculty phd mnas female fellow in -20/l, clean 
*												Note: l=letter; as in 'last'

//3.END) Close the Log File and exit Do File.
log close
exit





