//6.1a) Set-up your do-file. 
capture log close
log using 	icpsrcda-06-count, replace text

//  program:    icpsrcda-06-count.do
//  task:       Review 6 - Count Models
//  project:    ICPSR CDA
//  author:     Trent Mize \ 2014-06-24
//	updated:	SNS		   \ 2017-07-16

*program setup
version 	14.0
clear 		all 
set 		linesize 80

// 6.1b) Load the Data.
usecda 	cda_scireview3

// 6.1c) Examine data, select variables, drop missing, and verify. 
codebook, 	compact
keep 		pub6 female phd enrol
misschk, 	gen(m)
tab 		mnumber
keep if 	mnumber==0
tab1 		pub6 
sum 		pub6 female phd enrol
codebook 	pub6 female phd enrol, compact

// 6.3) Estimate the Poisson and NBReg Regression Models. 
poisson 	pub6 i.female phd enrol, nolog
estimates 	store prm
nbreg 		pub6 i.female phd enrol, nolog
estimates 	store nbreg
esttab 		prm nbreg, z mti wide

// 6.7) Testing the NBRM vs. the PRM. 
nbreg 		pub6 female phd enrol, nolog

// 6.8) Factor Changes. 
listcoef, 	help

// 6.10) Calcuating Discrete Changes. 
mchange, atmeans

// 6.11) Predicted Rate and Probabilities. 
mchange female, stats(ci)
mchange female, stats(ci) pr(0/9)

// 6.12) ZIP and ZINB Models. 
zip 	pub6 female phd enrol, inf(phd) nolog
zinb 	pub6 female phd enrol, inf(phd) nolog

// 6.13) Factor Change. 
qui 		zinb pub6 female phd enrol, inf(phd)
listcoef, 	help

// 6.14) Comparing probabilites of a 0 from PRM and NBRM
qui 	poisson 	pub6 female phd enrol, nolog
mgen, 	at(phd=(1(1)5)) atmeans stub(prm) pr(0/9)

qui 	nbreg 		pub6 female phd enrol, nolog
mgen, 	at(phd=(1(1)5)) atmeans stub(nbrm) pr(0/9)

graph twoway ///
	(rarea prmll0 prmul0 prmphd, col(gs14)) ///
	(rarea nbrmll0 nbrmul0 prmphd, col(gs14)) ///
	(connected prmpr0 prmphd, lpat(dash) lcol(green) msym(i) ) ///
	(connected nbrmpr0 prmphd, lpat(solid) lcol(blue) msym(i) ), ///
	ylab(0(.1).4, grid gmax gmin) ytitle("Pr(y = 0)") ///
	legend(on order(3 4)) 
	
graph export icpsrcda06-count-fig1.png, width(1200) replace 

// 6.15) Compare models using countfit. 
countfit pub6 female phd enrol, inf( phd) ///
	graph(icpsrcda06-count-fig2.png , width(1200) replace)

// 6.END) Close the Log File.
log close
exit







